@@ -19,12 +19,14 @@
 
 #include "myrightsjob.h"
 
+#include <KLocalizedString>
+
 #include "acljobbase_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class MyRightsJobPrivate : public AclJobBasePrivate
 {
@@ -36,10 +38,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 MyRightsJob::MyRightsJob(Session *session)
-    : AclJobBase(*new MyRightsJobPrivate(session, "MyRights"))
+    : AclJobBase(*new MyRightsJobPrivate(session, i18n("MyRights")))
 {
 }
 
@@ -51,7 +53,7 @@ void MyRightsJob::doStart()
 {
     Q_D(MyRightsJob);
 
-    d->sendCommand("MYRIGHTS", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("MYRIGHTS", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void MyRightsJob::handleResponse(const Message &response)
